@@ -19,10 +19,11 @@
 #include "filerenamer.h"
 
 #include <algorithm>
+#include <utility>
 
 #include <kiconloader.h>
 #include <KLocalizedString>
-#include <kio/job.h>
+#include <KIO/FileCopyJob>
 #include <kdesktopfile.h>
 #include <kconfiggroup.h>
 #include <KSharedConfig>
@@ -39,6 +40,7 @@
 #include <QLabel>
 #include <QPixmap>
 #include <QFrame>
+#include <QStandardPaths>
 #include <QTreeWidget>
 #include <QScrollBar>
 #include <QPushButton>
@@ -54,6 +56,24 @@
 #include "playlist.h" // processEvents()
 #include "playlistitem.h"
 
+using namespace Qt::Literals::StringLiterals;
+using std::as_const;
+
+static QString defaultMusicDir()
+{
+    const QString defaultDir(QStandardPaths::writableLocation(QStandardPaths::MusicLocation));
+    const QString home(QDir::homePath());
+
+    // replace home dir path with ~, if present
+
+    if(defaultDir.startsWith(home)) {
+        return u"~"_s + defaultDir.sliced(home.length());
+    }
+    else {
+        return defaultDir;
+    }
+}
+
 class ConfirmationDialog : public QDialog
 {
 public:
@@ -96,15 +116,13 @@ public:
 
         int lvHeight = 0;
 
-        QMap<QString, QString>::ConstIterator it = files.constBegin();
-        for(; it != files.constEnd(); ++it) {
+        for(const auto [oldName, newName] : files.asKeyValueRange()) {
             QTreeWidgetItem *item = new QTreeWidgetItem(lv);
-            item->setText(0, it.key());
+            item->setText(0, oldName);
 
-            if (it.key() != it.value()) {
-                item->setText(1, it.value());
+            if (oldName != newName) {
+                item->setText(1, newName);
             }
-
             else {
                 item->setText(1, i18n("No Change"));
             }
@@ -125,24 +143,18 @@ public:
 // Implementation of ConfigCategoryReader
 //
 
-ConfigCategoryReader::ConfigCategoryReader() : CategoryReaderInterface(),
-    m_currentItem(0)
+ConfigCategoryReader::ConfigCategoryReader()
+  : CategoryReaderInterface()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "FileRenamer");
+    KConfigGroup config(KSharedConfig::openConfig(), u"FileRenamer"_s);
 
-    QList<int> categoryOrder = config.readEntry("CategoryOrder", QList<int>());
+    const QList<int> defaultCategories = { Artist, Album, Title, Track };
+    const QList<int> categoryOrder = config.readEntry("CategoryOrder", defaultCategories);
     int categoryCount[NumTypes] = { 0 }; // Keep track of each category encountered.
 
-    // Set a default:
-
-    if(categoryOrder.isEmpty())
-        categoryOrder << Artist << Album << Title << Track;
-
-    QList<int>::ConstIterator catIt = categoryOrder.constBegin();
-    for(; catIt != categoryOrder.constEnd(); ++catIt)
-    {
-        int catCount = categoryCount[*catIt]++;
-        TagType category = static_cast<TagType>(*catIt);
+    for(int catIdx : categoryOrder) {
+        int catCount = categoryCount[catIdx]++;
+        TagType category = static_cast<TagType>(catIdx);
         CategoryID catId(category, catCount);
 
         m_options[catId] = TagRenamerOptions(catId);
@@ -151,15 +163,14 @@ ConfigCategoryReader::ConfigCategoryReader() : CategoryReaderInterface(),
 
     m_folderSeparators.fill(false, m_categoryOrder.count() - 1);
 
-    QList<int> checkedSeparators = config.readEntry("CheckedDirSeparators", QList<int>());
+    const auto checkedSeparators = config.readEntry("CheckedDirSeparators", QList<int>());
 
-    QList<int>::ConstIterator it = checkedSeparators.constBegin();
-    for(; it != checkedSeparators.constEnd(); ++it) {
-        if(*it < m_folderSeparators.count())
-            m_folderSeparators[*it] = true;
+    for(int sepIdx : checkedSeparators) {
+        if(sepIdx < m_folderSeparators.count())
+            m_folderSeparators[sepIdx] = true;
     }
 
-    m_musicFolder = config.readPathEntry("MusicFolder", "${HOME}/music");
+    m_musicFolder = config.readPathEntry("MusicFolder", defaultMusicDir());
     m_separator = config.readEntry("Separator", " - ");
 }
 
@@ -293,19 +304,19 @@ FileRenamerWidget::FileRenamerWidget(QWidget *parent) :
 void FileRenamerWidget::loadConfig()
 {
     QList<int> checkedSeparators;
-    KConfigGroup config(KSharedConfig::openConfig(), "FileRenamer");
+    KConfigGroup config(KSharedConfig::openConfig(), u"FileRenamer"_s);
 
     for(int i = 0; i < m_rows.count(); ++i)
         m_rows[i].options = TagRenamerOptions(m_rows[i].category);
 
     checkedSeparators = config.readEntry("CheckedDirSeparators", QList<int>());
 
-    foreach(int separator, checkedSeparators) {
+    for(int separator : as_const(checkedSeparators)) {
         if(separator < m_folderSwitches.count())
             m_folderSwitches[separator]->setChecked(true);
     }
 
-    QString path = config.readEntry("MusicFolder", "${HOME}/music");
+    QString path = config.readEntry("MusicFolder", defaultMusicDir());
     m_ui->m_musicFolder->setUrl(QUrl::fromLocalFile(path));
     m_ui->m_musicFolder->setMode(KFile::Directory |
                                  KFile::ExistingOnly |
@@ -316,7 +327,7 @@ void FileRenamerWidget::loadConfig()
 
 void FileRenamerWidget::saveConfig()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "FileRenamer");
+    KConfigGroup config(KSharedConfig::openConfig(), u"FileRenamer"_s);
     QList<int> checkedSeparators;
     QList<int> categoryOrder;
 
@@ -464,7 +475,7 @@ bool FileRenamerWidget::removeRow(int id)
     // The checkbox is contained within a layout widget, so the layout
     // widget is the one the needs to die.
     delete m_folderSwitches[checkboxPosition]->parent();
-    m_folderSwitches.erase(&m_folderSwitches[checkboxPosition]);
+    m_folderSwitches.removeAll(m_folderSwitches[checkboxPosition]);
 
     // Go through all the rows and if they have the same category and a
     // higher categoryNumber, decrement the number.  Also update the
@@ -490,7 +501,7 @@ bool FileRenamerWidget::removeRow(int id)
     for(int i = id + 1; i < m_rows.count(); ++i)
         assignPositionHandlerForRow(m_rows[i]);
 
-    m_rows.erase(&m_rows[id]);
+    m_rows.remove(id);
 
     // Make sure we update the buttons of affected rows.
     m_rows[idOfPosition(0)].upButton->setEnabled(false);
@@ -522,7 +533,7 @@ void FileRenamerWidget::addFolderSeparatorCheckbox()
 
 void FileRenamerWidget::createTagRows()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "FileRenamer");
+    KConfigGroup config(KSharedConfig::openConfig(), u"FileRenamer"_s);
     QList<int> categoryOrder = config.readEntry("CategoryOrder", QList<int>());
 
     if(categoryOrder.isEmpty())
@@ -873,15 +884,15 @@ void FileRenamer::rename(const PlaylistItemList &items)
     QMap<QString, QString> map;
     QMap<QString, PlaylistItem *> itemMap;
 
-    for(PlaylistItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
-        reader.setPlaylistItem(*it);
-        QString oldFile = (*it)->file().absFilePath();
-        QString extension = (*it)->file().fileInfo().suffix();
+    for(PlaylistItem *item : as_const(items)) {
+        reader.setPlaylistItem(item);
+        QString oldFile = item->file().absFilePath();
+        QString extension = item->file().fileInfo().suffix();
         QString newFile = fileName(reader) + '.' + extension;
 
         if(oldFile != newFile) {
             map[oldFile] = newFile;
-            itemMap[oldFile] = *it;
+            itemMap[oldFile] = item;
         }
     }
 
@@ -889,24 +900,20 @@ void FileRenamer::rename(const PlaylistItemList &items)
         return;
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
-    for(QMap<QString, QString>::ConstIterator it = map.constBegin();
-        it != map.constEnd(); ++it)
-    {
-        if(moveFile(it.key(), it.value())) {
-            itemMap[it.key()]->setFile(it.value());
-            itemMap[it.key()]->refresh();
+    for(const auto &[oldFile, newFile] : as_const(map).asKeyValueRange()) {
+        if(moveFile(oldFile, newFile)) {
+            itemMap[oldFile]->setFile(newFile);
+            itemMap[oldFile]->refresh();
 
-            setFolderIcon(QUrl::fromLocalFile(it.value()), itemMap[it.key()]);
+            setFolderIcon(QUrl::fromLocalFile(newFile), itemMap[oldFile]);
         }
         else
-            errorFiles << i18n("%1 to %2", it.key(), it.value());
-
-        processEvents();
+            errorFiles << i18n("%1 to %2", oldFile, newFile);
     }
     QApplication::restoreOverrideCursor();
 
     if(!errorFiles.isEmpty())
-        KMessageBox::errorList(0, i18n("The following rename operations failed:\n"), errorFiles);
+        KMessageBox::errorList(nullptr, i18n("The following rename operations failed:\n"), errorFiles);
 }
 
 bool FileRenamer::moveFile(const QString &src, const QString &dest)
@@ -940,16 +947,14 @@ void FileRenamer::setFolderIcon(const QUrl &dstURL, const PlaylistItem *item)
 
     // Split path, and go through each path element.  If a path element has
     // the album information, set its folder icon.
-    QStringList elements = dstURL.path().split('/',
-            Qt::SkipEmptyParts
-            );
+    const QStringList elements = dstURL.path().split('/', Qt::SkipEmptyParts);
     QString path;
 
-    for(QStringList::ConstIterator it = elements.constBegin(); it != elements.constEnd(); ++it) {
-        path.append('/' + (*it));
+    for(const QString &pathPart : elements) {
+        path.append('/' + pathPart);
 
         qCDebug(JUK_LOG) << "Checking path: " << path;
-        if((*it).contains(item->file().tag()->album()) &&
+        if(pathPart.contains(item->file().tag()->album()) &&
            QDir(path).exists() &&
            !QFile::exists(path + "/.directory"))
         {
@@ -979,10 +984,9 @@ void FileRenamer::setFolderIcon(const QUrl &dstURL, const PlaylistItem *item)
 QList<CategoryID>::ConstIterator lastEnabledItem(const QList<CategoryID> &list,
                                                  const CategoryReaderInterface &interface)
 {
-    QList<CategoryID>::ConstIterator it = list.constBegin();
-    QList<CategoryID>::ConstIterator last = list.constEnd();
+    auto last = list.end();
 
-    for(; it != list.constEnd(); ++it) {
+    for(auto it = list.begin(); it != list.end(); ++it) {
         if(interface.isRequired(*it) || (!interface.isDisabled(*it) &&
               !interface.categoryValue((*it).category).isEmpty()))
         {
@@ -1007,9 +1011,7 @@ QString FileRenamer::fileName(const CategoryReaderInterface &interface)
     lastEnabled = lastEnabledItem(categoryOrder, interface);
     bool pastLast = false; // Toggles to true once we've passed lastEnabled.
 
-    for(QList<CategoryID>::ConstIterator it = categoryOrder.constBegin();
-            it != categoryOrder.constEnd();
-            ++it, ++i)
+    for(auto it = categoryOrder.begin(); it != categoryOrder.end(); ++it, ++i)
     {
         if(it == lastEnabled)
             pastLast = true;
@@ -1036,13 +1038,13 @@ QString FileRenamer::fileName(const CategoryReaderInterface &interface)
 
     QString result;
 
-    for(QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); /* Empty */) {
+    for(auto it = list.cbegin(); it != list.cend(); /* Empty */) {
         result += *it;
 
         ++it; // Manually advance iterator to check for end-of-list.
 
         // Add separator unless at a directory boundary
-        if(it != list.constEnd() &&
+        if(it != list.cend() &&
            !(*it).startsWith(dirSeparator) && // Check beginning of next item.
            !result.endsWith(dirSeparator))
         {
