@@ -30,14 +30,18 @@
 #include <QDragMoveEvent>
 #include <QElapsedTimer>
 #include <QFileInfo>
+#include <QFont>
 #include <QHeaderView>
 #include <QIcon>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QMimeData>
 #include <QMouseEvent>
 #include <QTime>
 #include <QTimer>
 
+#include <utility>
+
 #include "actioncollection.h"
 #include "cache.h"
 #include "collectionlist.h"
@@ -56,6 +60,7 @@
 
 using namespace ActionCollection; // ""_act and others
 using namespace IconSupport;      // ""_icon
+using std::as_const;
 
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox public methods
@@ -82,7 +87,7 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
     header()->hide();
     header()->blockSignals(false);
 
-    setSelectionMode(QAbstractItemView::ExtendedSelection);
+    setSelectionMode(QAbstractItemView::SingleSelection);
 
     m_contextMenu = new QMenu(this);
 
@@ -140,6 +145,8 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
 
     connect(this, &PlaylistBox::signalPlayFile,
             player, qOverload<const FileHandle &>(&PlayerManager::play));
+    connect(player, &PlayerManager::signalStop,
+            this, &PlaylistBox::slotClearPlayingIndicators);
 
     const auto *tagManager = TagTransactionManager::instance();
     connect(tagManager, &TagTransactionManager::signalAboutToModifyTags,
@@ -236,6 +243,9 @@ void PlaylistBox::scanFolders()
 
 bool PlaylistBox::requestPlaybackFor(const FileHandle &file)
 {
+    slotClearPlayingIndicators();
+    m_playlistDict[currentPlaylist()]->setPlaying(true);
+
     emit signalPlayFile(file);
     return true;
 }
@@ -418,7 +428,7 @@ void PlaylistBox::remove()
 
         if(remove == yesButton) {
             QStringList couldNotDelete;
-            for(const auto &playlistFile : qAsConst(files)) {
+            for(const auto &playlistFile : as_const(files)) {
                 if(!QFile::remove(playlistFile))
                     couldNotDelete.append(playlistFile);
             }
@@ -460,7 +470,7 @@ void PlaylistBox::remove()
 
 void PlaylistBox::setDynamicListsFrozen(bool frozen)
 {
-    for(auto &playlistBoxItem : qAsConst(m_viewModes)) {
+    for(auto &playlistBoxItem : as_const(m_viewModes)) {
         playlistBoxItem->setDynamicListsFrozen(frozen);
     }
 }
@@ -485,16 +495,31 @@ void PlaylistBox::slotShowDropTarget()
     if(m_dropItem) raise(m_dropItem->playlist());
 }
 
+void PlaylistBox::slotUpdatePlayingPlaylist()
+{
+    slotClearPlayingIndicators();
+    Playlist *p = currentPlaylist();
+    PlaylistBox::Item *item = m_playlistDict[p];
+    item->setPlaying(playing());
+}
+
+void PlaylistBox::slotClearPlayingIndicators()
+{
+    for(Item *item : as_const(m_playlistDict).values()) {
+        item->setPlaying(false);
+    }
+}
+
 void PlaylistBox::slotAddItem(const QString &tag, unsigned column)
 {
-    for(auto &viewMode : qAsConst(m_viewModes)) {
+    for(auto &viewMode : as_const(m_viewModes)) {
         viewMode->addItems(QStringList(tag), column);
     }
 }
 
 void PlaylistBox::slotRemoveItem(const QString &tag, unsigned column)
 {
-    for(auto &viewMode : qAsConst(m_viewModes)) {
+    for(auto &viewMode : as_const(m_viewModes)) {
         viewMode->removeItem(tag, column);
     }
 }
@@ -556,7 +581,7 @@ void PlaylistBox::dragMoveEvent(QDragMoveEvent* event)
 {
     QTreeWidget::dragMoveEvent(event);
 
-    Item* hovered_item = static_cast<Item*>(itemAt(event->pos()));
+    Item* hovered_item = static_cast<Item*>(itemAt(event->position().toPoint()));
     if(hovered_item != m_dropItem){
         m_dropItem = hovered_item;
         if(m_dropItem) m_showTimer->start();
@@ -643,6 +668,7 @@ void PlaylistBox::slotDoubleClicked(QTreeWidgetItem *item)
         return;
     auto *playlist = static_cast<Item *>(item)->playlist();
 
+    slotClearPlayingIndicators();
     playlist->slotBeginPlayback();
 }
 
@@ -684,14 +710,8 @@ void PlaylistBox::setupUpcomingPlaylist()
 
 void PlaylistBox::slotLoadCachedPlaylists()
 {
-    qCDebug(JUK_LOG) << "Loading cached playlists.";
-    QElapsedTimer stopwatch;
-    stopwatch.start();
-
     Cache::loadPlaylists(this);
 
-    qCDebug(JUK_LOG) << "Cached playlists loaded, took" << stopwatch.elapsed() << "ms";
-
     // Auto-save playlists after they change.
     m_savePlaylistTimer = new QTimer(this);
     m_savePlaylistTimer->setInterval(3000); // 3 seconds with no change? -> commit
@@ -728,9 +748,25 @@ PlaylistBox::Item::Item(Item *parent, const QString &icon, const QString &text,
     init();
 }
 
-PlaylistBox::Item::~Item()
+void PlaylistBox::Item::setPlaying(bool isPlaying)
 {
+    using namespace Qt::Literals::StringLiterals;
 
+    if(isPlaying) {
+        setBackground(0, QBrush(m_playlist->palette().alternateBase()));
+        setStatusTip(0, u"Playing"_s);
+
+        auto f = font(0);
+        f.setBold(true);
+        setFont(0, f);
+    }
+    else {
+        setBackground(0, QBrush());
+
+        auto f = font(0);
+        f.setBold(false);
+        setFont(0, f);
+    }
 }
 
 void PlaylistBox::Item::setup()
